#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-5yx3PScs45mBBbRib8el8e
key:                  persistent-test-2.13.1.3-5yx3PScs45mBBbRib8el8e
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  202bfd909159317c08fa76056851416d
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-5yx3PScs45mBBbRib8el8e
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-GpRd3MIUOiG9qPGcoKge2s
    aeson-2.2.2.0-EjtcViUIVMXBXClGtNnj1W base-4.18.2.1
    blaze-html-0.9.2.0-KZMAMNkPI6c1nayVkkxKRi bytestring-0.11.5.3
    conduit-1.3.6.1-6RhtQrDCVyFKlfTW6yY8Y8 containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-HXdhTTwZj8n5iD9pvKq7in
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-825QpMRoz01KPONvaq0oHX
    monad-control-1.0.3.1-6IsshVA91GrHbUhatsYJjO
    monad-logger-0.3.42-3QFkt83SVFoLS6ctdEFerC mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.1-GSkhBnL5ygC61RNhD7bs9B
    quickcheck-instances-0.3.33-I6wfByut7OO58kgkRHaiyK
    random-1.2.1.3-8T7wlm0rQ0t5wVCdHG7g6D
    resourcet-1.3.0-Gfh5MtoAdmp12NgGJUZ70s text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-D1yhIUlgzVqI0cyA8RcV0H
    unliftio-0.2.25.1-DscakO0OUYTI6rllvWargg
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-6KS41JVoQWZ5mM86HX5ZiJ

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

